@@ -8,10 +8,8 @@ macro_rules! handle_response {
 }
 
 pub(crate) mod string {
-    use std::fmt::Display;
-    use std::str::FromStr;
-
     use serde::{de, Deserialize, Deserializer};
+    use std::{fmt::Display, str::FromStr};
 
     pub fn deserialize<'de, T, D>(deserializer: D) -> Result<T, D::Error>
     where
@@ -19,9 +17,8 @@ pub(crate) mod string {
         T::Err: Display,
         D: Deserializer<'de>,
     {
-        String::deserialize(deserializer)?
-            .parse()
-            .map_err(de::Error::custom)
+        let s = <&'de str>::deserialize(deserializer)?;
+        s.parse().map_err(de::Error::custom)
     }
 
     pub fn deserialize_opt<'de, T, D>(deserializer: D) -> Result<Option<T>, D::Error>
@@ -30,10 +27,10 @@ pub(crate) mod string {
         T::Err: Display,
         D: Deserializer<'de>,
     {
-        match Option::<String>::deserialize(deserializer)? {
-            Some(s) => Ok(Some(s.parse().map_err(de::Error::custom)?)),
-            None => Ok(None),
-        }
+        Ok(match Option::<&'de str>::deserialize(deserializer)? {
+            Some(s) => Some(s.parse().map_err(de::Error::custom)?),
+            None => None,
+        })
     }
 }
 
@@ -46,16 +43,16 @@ pub(crate) mod datetime_opt {
     where
         D: Deserializer<'de>,
     {
-        match Option::<&'de str>::deserialize(deserializer)? {
+        Ok(match Option::<&'de str>::deserialize(deserializer)? {
             Some(s) => {
                 use chrono::TimeZone;
                 let ts: i64 = s.parse().map_err(de::Error::custom)?;
                 let dt = chrono::Utc.timestamp_millis(ts);
 
-                Ok(Some(dt))
+                Some(dt)
             }
-            None => Ok(None),
-        }
+            None => None,
+        })
     }
 
     #[allow(dead_code)]
